@@ -12,7 +12,9 @@ from magnumapi.cadata.RemFitDefinition import RemFitDefinition
 from magnumapi.cadata.StrandDefinition import StrandDefinition
 from magnumapi.cadata.TransientDefinition import TransientDefinition
 import magnumapi.tool_adapters.roxie.RoxieAPI as RoxieAPI
-from magnumapi.tool_adapters.DirectoryManager import DirectoryManager
+import magnumapi.commons.json_file as json_file
+import magnumapi.commons.text_file as text_file
+from magnumapi.commons.DirectoryManager import DirectoryManager
 
 T = TypeVar('T')
 
@@ -167,8 +169,7 @@ class CableDatabase:
         :param json_file_path: a path
         :return: a CableDatabase instance with initialized lists of definitions
         """
-        with open(json_file_path) as json_file:
-            data = json.load(json_file)
+        data = json_file.read(json_file_path)
 
         # Optional definitions
         if 'remfit' in data:
@@ -310,9 +311,7 @@ class CableDatabase:
                   ]
 
         # Write to a text file
-        with open(cadata_output_path, 'w') as file_write:
-            for output_el in output:
-                file_write.write(output_el + '\n\n')
+        text_file.writelines(cadata_output_path, output, endline='\n\n')
 
     @classmethod
     def _convert_definition_df_to_bottom_header_str(cls, df: pd.DataFrame, keyword: str) -> str:
