@@ -75,3 +75,33 @@ class GeometryCheck:
         l_arc = Line.calc_arc_length_between_two_lines(radius, line_last_area, line_first_area)
 
         return l_arc < min_value_in_mm
+
+    @classmethod
+    def is_bending_radius_too_small(cls, geometry, angle_bending_deg_min):
+        for layer_def in geometry.layer_defs:
+            block_index_last = layer_def.blocks[-1]
+            block_index = geometry.get_index_in_blocks_for_layer_block_index(block_index_last)
+            block_last = geometry.blocks[block_index]
+            phi_last_block = block_last.areas[-1].get_line(3).p1.get_phi()
+            angle_bending_deg = 90 - phi_last_block
+            print(angle_bending_deg)
+            if angle_bending_deg < angle_bending_deg_min:
+                return True
+
+        return False
+
+    @classmethod
+    def is_conductor_radiality_too_skewed(cls, geometry, radiality_max_angle_deg):
+        for block in geometry.blocks:
+            for area in block.areas:
+                first_line: Line = area.get_line(0)
+                # get phi angle
+                phi_angle = first_line.p1.get_phi()
+                # get alpha angle
+                alpha_angle = Line.calculate_relative_alpha_angle(first_line)
+                # check
+                if abs(alpha_angle - phi_angle) > radiality_max_angle_deg:
+                    print(abs(alpha_angle - phi_angle))
+                    return True
+
+        return False
