@@ -209,7 +209,7 @@ class CosThetaBlock(Block):
             raise AttributeError('In order to extract a homogenized block definition, areas need to be initialized!')
 
         inner_radius = self.block_def.radius
-        outer_radius = inner_radius + self.cable_def.width
+        outer_radius = inner_radius + self.cable_def.width + 2 * self.insul_def.width
 
         # write block corner angles
         # 4 ----- 3
