@@ -38,10 +38,18 @@ class LayerDefinition:
 
 class SlottedLayerDefinition(LayerDefinition):
 
-    def __init__(self, no: int, symm: int, typexy: int, spar_thickness: float, blocks: Union[str, list]) -> None:
+    def __init__(self,
+                 no: int,
+                 symm: int,
+                 typexy: int,
+                 spar_thickness: float,
+                 midplane_wedge_thickness: float,
+                 blocks: Union[str, list]) -> None:
         """ A constructor of a layer definition instance
 
         :param spar_thickness: a thickness of a layer spar in mm
+        :param midplane_wedge_thickness: a thickness of a midplane wedge in mm
         """
         super().__init__(no=no, symm=symm, typexy=typexy, blocks=blocks)
         self.spar_thickness = spar_thickness
+        self.midplane_wedge_thickness = midplane_wedge_thickness
