@@ -55,7 +55,7 @@ class Optimization(ABC):
                 try:
                     self.update_model(individual)
                     fom_dct = self.calculate_figures_of_merit(individual, {})
-                except AttributeError:
+                except (AttributeError, TypeError):
                     fom_dct = {objective_config.objective: float('nan') for objective_config in self.config.objectives}
                 fom_dcts.append(fom_dct)
 
@@ -167,11 +167,7 @@ class GeneticOptimization(Optimization, ABC):
         :param design_variables_df: a DataFrame with design variables
         :return: a list of design variables
         """
-        design_variables = []
-        for index, row in design_variables_df.iterrows():
-                design_variables.append(GeneticDesignVariable(**row.to_dict()))
-
-        return design_variables
+        return [GeneticDesignVariable(**row.to_dict()) for _, row in design_variables_df.iterrows()]
 
     @staticmethod
     def initialize_config(json_path: str) -> OptimizationConfig:
@@ -224,7 +220,7 @@ class GeneticOptimization(Optimization, ABC):
             # crossover and mutation
             for c in self.crossover(p1, p2):
                 # mutation
-                self.mutation(c)
+                c = self.mutation(c)
                 # store for next generation
                 children.append(c)
         # replace population
@@ -252,8 +248,8 @@ class GeneticOptimization(Optimization, ABC):
         return pop[selection_ix]
 
     def crossover(self, parent1: List[int], parent2: List[int]) -> Tuple[List[int], List[int]]:
-        """ Method performing a single cross-over operation between two parents and creates two children. The cross-over
-        point is selected at random.
+        """ Method performing a single cross-over operation between two parents and creates two children.
+        The cross-over point is selected at random.
 
         :param parent1: first parent
         :param parent2: second parent
@@ -416,7 +412,7 @@ class RoxieGeneticOptimization(GeneticOptimization):
 
         return block_variable_value
 
-    def decode_chromosome_programmable_geometry(self, individual: List[int]):
+    def decode_chromosome_programmable_geometry(self, individual: List[int]) -> dict:
         decoded = {}
         # remove nbl_layer and nco_layer from the list of design variables
         index_start = 0
@@ -484,8 +480,9 @@ class RoxieGeneticOptimization(GeneticOptimization):
             if ':-:' in block_variable:
                 variable, layer_index, block_index = block_variable.split(':')
                 block_index = int(block_index)
-                if variable == 'current':
-                    geometry_model.blocks[block_index - 1].block_def.current = value
+
+                if hasattr(geometry_model.blocks[block_index - 1].block_def, variable):
+                    setattr(geometry_model.blocks[block_index - 1].block_def, variable, value)
             elif ':' in block_variable:
                 variable, layer_index, block_layer_index = block_variable.split(':')
                 layer_index = int(layer_index)
@@ -493,16 +490,9 @@ class RoxieGeneticOptimization(GeneticOptimization):
 
                 no_block = geometry_model.layer_defs[layer_index - 1].blocks[block_layer_index - 1]
                 block_index = geometry_model.get_index_in_blocks_for_layer_block_index(no_block)
-                if variable == 'nco':
-                    geometry_model.blocks[block_index].block_def.nco = value
-                elif variable == 'alpha':
-                    geometry_model.blocks[block_index].block_def.alpha = value
-                elif variable == 'alpha_r':
-                    geometry_model.blocks[block_index].block_def.alpha_r = value
-                elif variable == 'phi':
-                    geometry_model.blocks[block_index].block_def.phi = value
-                elif variable == 'phi_r':
-                    geometry_model.blocks[block_index].block_def.phi_r = value
+
+                if hasattr(geometry_model.blocks[block_index].block_def, variable):
+                    setattr(geometry_model.blocks[block_index].block_def, variable, value)
 
         # Remove empty blocks
         return GeometryChange.update_layer_indexing(geometry_model)
@@ -670,7 +660,7 @@ class ParallelRoxieGeneticOptimization(RoxieGeneticOptimization):
                 try:
                     self.update_model(individual)
                     fom_dct = self.calculate_figures_of_merit(individual, {"index": index})
-                except AttributeError:
+                except (AttributeError, TypeError):
                     fom_dct = {objective_config.objective: float('nan') for objective_config in self.config.objectives}
 
                 fom_dcts.append(fom_dct)
