@@ -1,4 +1,5 @@
-import json
+import magnumapi.commons.json_file as json_file
+import magnumapi.commons.text_file as text_file
 
 
 def convert_notebook_to_script(input_ipynb_file_path: str, notebook_name: str, output_script_file_path: str) -> None:
@@ -10,8 +11,7 @@ def convert_notebook_to_script(input_ipynb_file_path: str, notebook_name: str, o
     :param notebook_name:
     :param output_script_file_path:
     """
-    with open(input_ipynb_file_path, 'r') as file:
-        notebook = json.load(file)
+    notebook = json_file.read(input_ipynb_file_path)
 
     parameters = []
     code_lines = []
@@ -40,7 +40,8 @@ def convert_notebook_to_script(input_ipynb_file_path: str, notebook_name: str, o
         if code_line.strip().startswith('from') or code_line.strip().startswith('import'):
             import_lines.append(code_line)
         else:
-            function_lines.append(code_line)
+            if not (code_line.startswith('%') or code_line.startswith('sys.path.append')):
+                function_lines.append(code_line)
 
     output_lines = list(import_lines)
 
@@ -54,6 +55,4 @@ def convert_notebook_to_script(input_ipynb_file_path: str, notebook_name: str, o
 
     output_lines.append('\t' + 'return ' + output_var)
 
-    with open(output_script_file_path, 'w') as file:
-        for output_line in output_lines:
-            file.write(output_line + '\n')
+    text_file.writelines(output_script_file_path, output_lines)
