@@ -30,18 +30,21 @@ class OptimizationCockpitWidget:
                  gen_opt: RoxieGeneticOptimization,
                  logger_df: pd.DataFrame,
                  config: OptimizationConfig,
-                 design_variables_df: pd.DataFrame) -> None:
+                 design_variables_df: pd.DataFrame,
+                 is_log_y=False) -> None:
         """ Constructor of an OptimizationCockpitWidget instance
 
         :param gen_opt: genetic optimization instance
         :param logger_df: a dataframe with logger
         :param config: optimization config instance
         :param design_variables_df: a dataframe with objective variables
+        :param is_log_y: if True, than the score plot has logarithmic y-scale
         """
         self.gen_opt = gen_opt
         self.min_logger_df = Logger.extract_min_rows_from_logger_df(logger_df, self.gen_opt.n_pop)
         self.config = config
         self.design_variables = initialize_design_variables(design_variables_df)
+        self.is_log_y = is_log_y
 
         fig = make_subplots(
             rows=3, cols=2,
@@ -140,10 +143,12 @@ class OptimizationCockpitWidget:
                 x=self.min_logger_df.index.values,
                 y=self.min_logger_df[SCORE_KEYWORD].values,
                 mode="lines+markers",
-                name="fitness"
+                name="fitness",
             ),
             row=row, col=col
         )
+        if self.is_log_y:
+            self.widget.update_yaxes(type='log', row=row, col=col)
 
     def display_objective_table(self, obj_df: pd.DataFrame) -> None:
         """ Method displaying the objective table in the widget
@@ -265,7 +270,8 @@ def initialize_design_variables(design_variables_df: pd.DataFrame) -> List[Cockp
     """
     design_variables = []
     for index, row in design_variables_df.iterrows():
-        design_variables.append(CockpitGeneticDesignVariable(GeneticDesignVariable(**row.to_dict())))
+        if 'layer' not in row['variable']:
+            design_variables.append(CockpitGeneticDesignVariable(GeneticDesignVariable(**row.to_dict())))
 
     return design_variables
 
