@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from typing import List
-import json
+import magnumapi.commons.json_file as json_file
 
 from magnumapi.optimization.ObjectiveConfig import ObjectiveConfig
 from magnumapi.optimization.OptimizationNotebookConfig import OptimizationNotebookConfig
@@ -60,8 +60,7 @@ class OptimizationConfig:
         :param json_path: a path to a json file with config
         :return: initialized OptimizationConfig instance
         """
-        with open(json_path) as f:
-            data = json.load(f)
+        data = json_file.read(json_path)
 
         input_folder = data['input_folder']
         output_folder = data['output_folder']
@@ -93,6 +92,7 @@ class OptimizationConfig:
         for config_objective in self.objectives:
             if config_objective.objective == objective:
                 return config_objective.weight
+
         raise KeyError('Objective name %s not present in objective configs.' % objective)
 
     def get_constraint(self, objective: str) -> float:
@@ -105,4 +105,5 @@ class OptimizationConfig:
         for config_objective in self.objectives:
             if config_objective.objective == objective:
                 return config_objective.constraint
+
         raise KeyError('Objective name %s not present in objective configs.' % objective)
