@@ -1,7 +1,9 @@
 from typing import List
+import os
 
 from magnumapi.geometry.Geometry import HomogenizedCosThetaGeometry
 from magnumapi.geometry.SlottedGeometry import SlottedHomogenizedCosThetaGeometry
+import magnumapi.commons.text_file as text_file
 
 
 class AnsysInputBuilder:
@@ -9,6 +11,18 @@ class AnsysInputBuilder:
 
     """
 
+    @classmethod
+    def update_input_template(cls, template_path: str, index: int, input_dir: str, input_file: str):
+        # read template file
+        template_content = text_file.read(template_path)
+
+        # update template file with index
+        template_content = template_content.format(index)
+
+        # write updated template file to output directory with index
+        output_path = os.path.join(input_dir, input_file % index)
+        text_file.write(output_path, template_content)
+
     @classmethod
     def write_geometry_input_file(cls, homo_geometry: HomogenizedCosThetaGeometry, model_path: str) -> None:
         """ Class method writing a geometry parameters for ANSYS input file from a homogenized cos-theta geometry
@@ -16,25 +30,16 @@ class AnsysInputBuilder:
         :param homo_geometry: a homogenized cos-theta geometry
         :param model_path: a path to model input
         """
-        output_text = cls.prepare_ansys_model_input(homo_geometry)
+        output_text = cls.generate_ansys_input_text(homo_geometry)
+        text_file.writelines(model_path, output_text)
 
-        with open(model_path, 'w') as file_write:
-            for output_text_el in output_text:
-                file_write.write(output_text_el + '\n')
+    @classmethod
+    def write_geometry_input_file_sm_ct(cls, homo_geometry, model_path):
+        output_text = cls.generate_ansys_input_text_sm_ct(homo_geometry)
+        text_file.writelines(model_path, output_text)
 
     @staticmethod
-    def prepare_ansys_model_input(homo_geometry: HomogenizedCosThetaGeometry) -> List[str]:
-        """ Static method preparing an ANSYS model input
-
-        :param homo_geometry:
-        :return:
-        """
-        n_layers = homo_geometry.get_number_of_layers()
-        blocks_per_layer = homo_geometry.get_number_of_blocks_per_layer()
-        return AnsysInputBuilder.generate_ansys_input_text(homo_geometry, n_layers, blocks_per_layer)
-
-    @staticmethod
-    def generate_ansys_input_text(homo_geometry: HomogenizedCosThetaGeometry, n_layers, blocks_per_layer) -> List[str]:
+    def generate_ansys_input_text(homo_geometry: HomogenizedCosThetaGeometry) -> List[str]:
         """ Method generating an ANSYS coil geometry input text from a homogenized cos-theta geometry
 
         :param homo_geometry: homogenized cos-theta geometry
@@ -42,6 +47,8 @@ class AnsysInputBuilder:
         :param blocks_per_layer: number of blocks per layer
         :return: a list of model inputs
         """
+        n_layers = homo_geometry.get_number_of_layers()
+        blocks_per_layer = homo_geometry.get_number_of_blocks_per_layer()
         model_inputs = []
         model_inputs.append('! Example Input File\n')
         model_inputs.append('! -------------------\n')
@@ -151,3 +158,76 @@ class AnsysInputBuilder:
         model_inputs.append('mu_ss_iron = mu_single\n')
 
         return model_inputs
+
+    @staticmethod
+    def generate_ansys_input_text_sm_ct(geometry: SlottedHomogenizedCosThetaGeometry):
+        output_text = []
+        output_text.append('! Number of layers')
+        n_layers = geometry.get_number_of_layers()
+        output_text.append('*set,n_lay,%d' % n_layers)
+
+        output_text.append('! vector with r-coo of layers inner and outer (columns)')
+        output_text.append('*dim,n_lay_r_vec,array,%d,2' % n_layers)
+
+        radius_outer_prev = None
+        for index_layer, layer_def in enumerate(geometry.layer_defs):
+            index_in_blocks = geometry.get_index_in_blocks_for_layer_block_index(layer_def.blocks[0])
+            block = geometry.blocks[index_in_blocks]
+            if index_layer == 0:
+                inner_rad = geometry.r_aperture
+            else:
+                inner_rad = radius_outer_prev
+
+            output_text.append('*set,n_lay_r_vec(%d,1),%.2fe-3' % (index_layer + 1, inner_rad))
+            output_text.append('*set,n_lay_r_vec(%d,2),%.2fe-3' % (index_layer + 1, block.block_def.radius_outer))
+
+            radius_outer_prev = block.block_def.radius_outer
+
+        output_text.append('! vector with number of blocks per layer')
+        output_text.append('*dim,n_lay_block_vec,array,%d,1' % n_layers)
+        for index_layer, layer_def in enumerate(geometry.layer_defs):
+            output_text.append('*set,n_lay_block_vec(%d,1),%d'% (index_layer + 1, len(layer_def.blocks)))
+
+        output_text.append('! total number of blocks')
+        output_text.append('*set,n_tot_block,%d' % len(geometry.blocks))
+
+        output_text.append('! vector with current (columns) of blocks')
+        output_text.append('*dim,n_block_curr_vec,array,%d,1' % len(geometry.blocks))
+        output_text.append('*dim,n_block_nco_vec,array,%d,1' % len(geometry.blocks))
+        for index_block, block in enumerate(geometry.blocks):
+            output_text.append('*set,n_block_curr_vec(%d,1),%.2f' % (index_block + 1, block.block_def.current))
+
+        output_text.append('! vector with r-coo of four corners (columns) of blocks (cyl coo)')
+        output_text.append('*dim,n_block_r_vec,array,%d,4' % len(geometry.blocks))
+        for index_block, block in enumerate(geometry.blocks):
+            output_text.append('*set,n_block_r_vec(%d,1),%.2fe-3' % (index_block + 1, block.block_def.radius_inner))
+            output_text.append('*set,n_block_r_vec(%d,2),%.2fe-3' % (index_block + 1, block.block_def.radius_inner))
+            output_text.append('*set,n_block_r_vec(%d,3),%.2fe-3' % (index_block + 1, block.block_def.radius_outer))
+            output_text.append('*set,n_block_r_vec(%d,4),%.2fe-3' % (index_block + 1, block.block_def.radius_outer))
+
+        output_text.append('! vector with a-coo of four corners (columns) of blocks (cyl coo)')
+        output_text.append('*dim,n_block_a_vec,array,%d,4' % len(geometry.blocks))
+        for index_block, block in enumerate(geometry.blocks):
+            output_text.append('*set,n_block_a_vec(%d,1),%.2f' % (index_block + 1, block.block_def.phi_3))
+            output_text.append('*set,n_block_a_vec(%d,2),%.2f' % (index_block + 1, block.block_def.phi_0))
+            output_text.append('*set,n_block_a_vec(%d,3),%.2f' % (index_block + 1, block.block_def.phi_1))
+            output_text.append('*set,n_block_a_vec(%d,4),%.2f' % (index_block + 1, block.block_def.phi_2))
+
+        output_text.append('! vector with number of conductors (columns) of blocks')
+        output_text.append('*dim,n_block_cond_vec,array,%d,1' % len(geometry.blocks))
+        for index_block, block in enumerate(geometry.blocks):
+            output_text.append('*set,n_block_cond_vec(%d,1),%d' % (index_block + 1, block.block_def.nco))
+
+        output_text.append('! vector with spar thickness (column) of layers')
+        output_text.append('*dim,n_lay_spar_th_vec,array,%d,1' % n_layers)
+
+        for layer_index, layer_def in enumerate(geometry.layer_defs):
+            output_text.append('*set,n_lay_spar_th_vec(%d,1),%.2fe-3' % (layer_index + 1, layer_def.spar_thickness))
+
+        output_text.append('*set,inter_lay_ins,0.5e-3')
+        output_text.append('*set,backbone_x,12.0e-3')
+        output_text.append('*set,backbone_y,6.0e-3')
+        output_text.append('*set,backbone_r,4.0e-3')
+        output_text.append('*set,backbone_r2,4.5e-3')
+
+        return output_text
