@@ -10,10 +10,7 @@ import plotly.express as px
 
 from magnumapi.tool_adapters.ToolAdapter import ToolAdapter
 import magnumapi.tool_adapters.roxie.RoxieAPI as RoxieAPI
-
-END_OF_ROXIE_CALCULATION = '     *                 END OF THIS ROXIE CALCULATION                 * '
-
-print('Loaded Tool Adapter version 0.0.1 for ROXIE VERS.10, UPDATE 3.1, 2015')
+import magnumapi.commons.text_file as text_file
 
 
 class RoxieToolAdapter(ToolAdapter):
@@ -22,14 +19,26 @@ class RoxieToolAdapter(ToolAdapter):
 
     """
 
-    def __init__(self, data_file_path: str, output_file_path: str) -> None:
-        """ A constructor initializing a RoxieToolAdapter instance
+    def __init__(self,
+                 input_folder_rel_dir: str,
+                 input_file: str,
+                 output_file: str,
+                 cadata_file: str,
+                 xml_output_file: str) -> None:
+        """ A constructor of a RoxieToolAdapter instance
 
-        :param data_file_path: a path to a data file, .data
-        :param output_file_path: a path to an output file, .output
+        :param input_folder_rel_dir: a relative path to a directory with inputs
+        :param input_file_path: a name of an input file, .data
+        :param output_file_path: a name of an output file, .output
+        :param cadata_file_path: a name of a cadata file, .cadata
+        :param xml_output_file_path: a name of an xml output file with plots, .xml
         """
-        self.data_file_path = data_file_path
-        self.output_file_path = output_file_path
+        self.input_folder_rel_dir = input_folder_rel_dir
+        self.input_file_path = os.path.join(input_folder_rel_dir, input_file)
+        self.output_file_path = os.path.join(input_folder_rel_dir, output_file)
+        self.cadata_file_path = os.path.join(input_folder_rel_dir, cadata_file)
+        self.cadata_file = cadata_file
+        self.xml_output_file_path = os.path.join(input_folder_rel_dir, xml_output_file)
         self.output_lines = []
 
     def run(self) -> None:
@@ -38,51 +47,25 @@ class RoxieToolAdapter(ToolAdapter):
             os.remove(self.output_file_path)
 
         # Different execution modes depending on the operating system
-        if platform.system() == 'Windows':
-            command = ['docker', 'exec', 'roxie_terminal', 'runroxie', self.data_file_path.replace('\\', '/')]
-        else:
-            command = ['runroxie', self.data_file_path]
-
+        command = self._get_process_command()
         p = Popen(command, stdin=PIPE, stdout=PIPE, stderr=PIPE)
-        byte_output, err = p.communicate(b"input data that is passed to subprocess' stdin")
-        rc = p.returncode
+        byte_output, _ = p.communicate(b"input data that is passed to subprocess' stdin")
 
         byte_output_decode = byte_output.decode()
         self.output_lines = byte_output_decode.split('\n')
 
-    def wait_until_output_exist(self, timeout_in_sec=10) -> None:
-        """ Method waiting until an output file exists. The waiting time is given as an argument. In case of a timeout
-         a FileNotFoundError is raised
+    def _get_process_command(self) -> list:
+        """ Private method returning a command for a process instantiation
 
-        :param timeout_in_sec: timeout in seconds
         """
-        output_file_path_corrected = self.output_file_path.replace('\\', '/')
-        count = 0
-        while not os.path.isfile(output_file_path_corrected) and count < timeout_in_sec:
-            time.sleep(1)
-            count += 1
-
-        if not os.path.isfile(output_file_path_corrected):
-            raise FileNotFoundError('The file %s does not exist!' % output_file_path_corrected)
-
-    @staticmethod
-    def unlink_file(file_path: str) -> None:
-        """ Static method unlinking a file that otherwise causes an error in copying files
-
-        :param file_path: a path to a file to unlink
-        """
-        try:
-            os.unlink(file_path)
-        except:
-            print('File does not exist' % file_path)
+        raise NotImplementedError('This method is not implemented for this class')
 
     def display_output(self) -> None:
         """ Method displaying output in case of ROXIE simulation failure
 
         """
-        if END_OF_ROXIE_CALCULATION not in self.output_lines:
-            for output_line in self.output_lines:
-                print(output_line)
+        for output_line in self.output_lines:
+            print(output_line)
 
     @staticmethod
     def convert_figures_of_merit_to_dict(fom_df: pd.DataFrame) -> dict:
@@ -183,8 +166,7 @@ class RoxieToolAdapter(ToolAdapter):
         :param field: actual field in tesla
         :param target_field: target field in tesla
         """
-        with open(roxie_force_input_path, 'r') as file_read:
-            roxie_force_txt = file_read.readlines()
+        roxie_force_txt = text_file.readlines(roxie_force_input_path)
 
         # # convert text input to a list of floats
         scaling = (target_field / field) ** 2
@@ -208,11 +190,113 @@ class RoxieToolAdapter(ToolAdapter):
         :param input_xml_path: path of an input XML file
         :param output_xml_path: path of an output, corrected XML file
         """
-        with open(input_xml_path, 'r') as file:
-            xml_lines = file.read()
+        xml_lines = text_file.read(input_xml_path)
+
         # get rid of an extra first line and a starting empty space in the second line
         if xml_lines[:2] == '\n ':
             xml_lines = xml_lines[2:]
 
-        with open(output_xml_path, 'w') as file:
-            file.write(xml_lines)
+        text_file.write(output_xml_path, xml_lines)
+
+
+class TerminalRoxieToolAdapter(RoxieToolAdapter):
+
+    def __init__(self,
+                 input_folder_rel_dir: str,
+                 input_file: str,
+                 output_file: str,
+                 cadata_file: str,
+                 xml_output_file: str,
+                 executable_name: str = 'runroxie'
+                 ):
+        """ Constructor of a TerminalRoxieToolAdapter object
+
+        :param input_folder_rel_dir: a relative path to input folder w.r.t. notebook location
+        :param input_file: a name of an input file
+        :param output_file: a name of an output file. It is the input file name with .output extension
+        :param cadata_file: a name of a cadata file
+        :param xml_output_file: a name of an output XML file with plot information from ROXIE
+        :param executable_name: name of ROXIE executable, typically runroxie
+        """
+        super().__init__(input_folder_rel_dir=input_folder_rel_dir,
+                         input_file=input_file,
+                         output_file=output_file,
+                         cadata_file=cadata_file,
+                         xml_output_file=xml_output_file)
+        self.executable_name = executable_name
+
+    def _get_process_command(self):
+        return [self.executable_name, self.input_file_path]
+
+
+class DockerTerminalRoxieToolAdapter(TerminalRoxieToolAdapter):
+
+    def __init__(self,
+                 input_folder_rel_dir: str,
+                 input_file: str,
+                 output_file: str,
+                 cadata_file: str,
+                 xml_output_file: str,
+                 executable_name: str = 'runroxie',
+                 docker_image_name: str = 'roxie_terminal'
+                 ):
+        """ Constructor of a DockerTerminalRoxieToolAdapter object
+
+        :param input_folder_rel_dir: a relative path to input folder w.r.t. notebook location
+        :param input_file: a name of an input file
+        :param output_file: a name of an output file. It is the input file name with .output extension
+        :param cadata_file: a name of a cadata file
+        :param xml_output_file: a name of an output XML file with plot information from ROXIE
+        :param executable_name: a name of ROXIE executable, typically runroxie
+        :param docker_image_name: a name of ROXIE Docker terminal image executable, typically roxie_terminal
+        """
+        super().__init__(input_folder_rel_dir=input_folder_rel_dir,
+                         input_file=input_file,
+                         output_file=output_file,
+                         cadata_file=cadata_file,
+                         xml_output_file=xml_output_file,
+                         executable_name=executable_name)
+        self.docker_image_name = docker_image_name
+        self.file_to_unlink = os.path.join(input_folder_rel_dir, 'm4_A.inp')
+
+    def run(self):
+        super().run()
+        self.wait_until_output_exist(timeout_in_sec=10)
+        self.unlink_file(self.file_to_unlink)
+
+    def _get_process_command(self):
+        if platform.system() == 'Windows':
+            input_file_path_temp = self.input_file_path.replace('\\', '/')
+        else:
+            input_file_path_temp = self.input_file_path
+
+        return ['docker', 'exec', self.docker_image_name, self.executable_name, input_file_path_temp]
+
+    def wait_until_output_exist(self, timeout_in_sec=10) -> None:
+        """ Method waiting until an output file exists. The waiting time is given as an argument. In case of a timeout
+         a FileNotFoundError is raised
+
+        :param timeout_in_sec: timeout in seconds
+        """
+        output_file_path_corrected = self.output_file_path.replace('\\', '/')
+        count = 0
+        while not os.path.isfile(output_file_path_corrected) and count < timeout_in_sec:
+            time.sleep(1)
+            count += 1
+
+        if not os.path.isfile(output_file_path_corrected):
+            raise FileNotFoundError('The file %s does not exist!' % output_file_path_corrected)
+
+    @staticmethod
+    def unlink_file(file_path: str) -> None:
+        """ Static method unlinking a file that otherwise causes an error in copying files
+
+        :param file_path: a path to a file to unlink
+        """
+        if platform.system() == 'Windows':
+            file_path = file_path.replace('\\', '/')
+
+        try:
+            os.unlink(file_path)
+        except:
+            print('File does not exist' % file_path)
