@@ -441,3 +441,41 @@ class TestRectangularBlock(TestCase):
         # assert
         if mock_show is not None:
             mock_show.assert_called()
+
+
+    # BLOCK 1
+    #     1     2     3           40            0            0        10000  SMC11T100   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current   condname  n1  n2  imag         turn
+
+    #  INSUL 1
+    # 28 TININS100          0.1          0.1 'Nb3Sn 100 um after rect.      '
+    # No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    # 100 SMC11T2         14.847        1.305        1.305    40           90           10 'Guess 2 for rect. of FNAL_NC  '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    # 106 SMC11T100     1 SMC11T2     HFMD07B   HFM46     TININS100 OST                1.9 'SMC Rect of FNAL_NC 35 turns  '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans              T_o  Comment
+
+    @patch("matplotlib.figure.Figure.show")
+    def test_homogenize(self, mock_show=None):
+        block_rel_def = RectangularBlockDefinition(x=40, y=0.0, alpha=0, nco=3, condname='SMC11T100', no=1,
+                                                   current=10000, type=2, n1=2, n2=20, imag=0, turn=0)
+
+        block = RectangularBlock(block_def=block_rel_def,
+                                 cable_def=self.cadata.get_cable_definition('SMC11T100'),
+                                 insul_def=self.cadata.get_insul_definition('SMC11T100'),
+                                 strand_def=self.cadata.get_strand_definition('SMC11T100'),
+                                 conductor_def=self.cadata.get_conductor_definition('SMC11T100'))
+
+        block.build_block()
+
+        block_homo = block.homogenize()
+        block_homo.build_block()
+
+        assert abs(block_homo.block_def.x - 40.0) <  1e-6
+        assert abs(block_homo.block_def.y - 0.0) <  1e-6
+        assert abs(block_homo.block_def.x_up_r - 55.047) <  1e-6
+        assert abs(block_homo.block_def.y_up_r - 4.515) <  1e-6
