@@ -16,7 +16,7 @@ class TestRectangularGeometry(unittest.TestCase):
     def test_build_geometry_rectangle_with_dict(self, mock_show=None):
         # arrange
         block_def = [
-            {'no': 1, 'x': 40.0, 'y': 0, 'alpha': 0.0, 'nco': 3, 'type': 2, 'current': 13500,
+            {'no': 1, 'radius': 40.0, 'phi': 0, 'alpha': 0.0, 'nco': 3, 'type': 2, 'current': 13500,
              'condname': 'SMC11T100', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
         layer_def = [{"no": 1,"symm": 1,"typexy": 1,"blocks": [1]}]
 
