@@ -200,3 +200,9 @@ class TestGeneticDesignVariable(TestCase):
 
         # assert
         self.assertListEqual([0, 1, 0, 1, 0], gene)
+
+class TestCockpitGeneticDesignVariable(TestCase):
+
+    def test(self):
+        pass
+
