@@ -83,7 +83,7 @@ class TestRoxieGeneticOptimization(TestCase):
                           'alpha_r:1:3': 6.40625, 'alpha_r:1:4': 6.5625, 'alpha_r:2:2': 0.46875, 'alpha_r:2:3': 0.9375,
                           'alpha_r:3:2': 9.6875, 'alpha_r:4:2': 7.8125, 'nco:1:1': 3, 'nco:1:2': 2, 'nco:1:3': 1,
                           'nco:1:4': 0, 'nco:2:1': 6, 'nco:2:2': 9, 'nco:2:3': 0, 'nco:3:1': 14, 'nco:3:2': 9,
-                          'nco:3:3': 3, 'nco:4:1': 30, 'nco:4:2': 12, 'R_EE:nan:': 1.2109375}
+                          'nco:3:3': 3, 'nco:4:1': 30, 'nco:4:2': 12, 'R_EE': 1.2109375}
 
         self.assertDictEqual(chromosome_ref, chromosome)
 
@@ -106,7 +106,7 @@ class TestRoxieGeneticOptimization(TestCase):
                           'alpha_r:2:3': 0.9375, 'alpha_r:3:2': 5.78125, 'alpha_r:3:3': 9.6875, 'alpha_r:4:2': 7.8125,
                           'nco:1:1': 3, 'nco:1:2': 2, 'nco:1:3': 1, 'nco:1:4': 0, 'nco:2:1': 6, 'nco:2:2': 9,
                           'nco:2:3': 0, 'nco:3:1': 14, 'nco:3:2': 9, 'nco:3:3': 3, 'nco:4:1': 30, 'nco:4:2': 12,
-                          'R_EE:nan:': 1.2109375, 'current:-:1': 12257.8125, 'current:-:2': 12257.8125,
+                          'R_EE': 1.2109375, 'current:-:1': 12257.8125, 'current:-:2': 12257.8125,
                           'current:-:3': 12257.8125, 'current:-:4': 12257.8125, 'current:-:5': 12257.8125,
                           'current:-:6': 12257.8125, 'current:-:7': 12257.8125, 'current:-:8': 12257.8125,
                           'current:-:9': 12257.8125, 'current:-:10': 12257.8125, 'current:-:11': 12257.8125,
@@ -388,7 +388,7 @@ class TestRoxieGeneticOptimization(TestCase):
         json_path = create_resources_file_path('resources/geometry/roxie/16T/16T_rel_slotted.json')
         cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
-        geometry_rel = GeometryFactory.init_with_json(json_path, cadata)
+        geometry_rel = GeometryFactory.init_slotted_with_json(json_path, cadata)
 
         # initialize design variables
         path_str = 'resources/optimization/design_variables_programmable_geometry.csv'
@@ -414,19 +414,19 @@ class TestRoxieGeneticOptimization(TestCase):
         assert geometry_rel.blocks[0].block_def.nco == decoded['nco:1:1']
         assert geometry_rel.blocks[1].block_def.nco == decoded['nco:1:2']
         assert geometry_rel.blocks[2].block_def.nco == decoded['nco:1:3']
-        assert abs(geometry_rel.blocks[0].block_def.phi_r - 0.5729399999999999) < 1e-6
+        assert abs(geometry_rel.blocks[0].block_def.phi_r - 1.038258941873985) < 1e-6
         assert abs(geometry_rel.blocks[1].block_def.phi_r - 2.076404240564713) < 1e-6
-        assert abs(geometry_rel.blocks[2].block_def.phi_r - 4.793637355826874) < 1e-6
+        assert abs(geometry_rel.blocks[2].block_def.phi_r - 4.920094195468366) < 1e-6
         assert geometry_rel.layer_defs[0].blocks == [1, 2, 3]
 
         assert geometry_rel.blocks[3].block_def.nco == decoded['nco:2:1']
         assert geometry_rel.blocks[4].block_def.nco == decoded['nco:2:2']
         assert geometry_rel.blocks[5].block_def.nco == decoded['nco:2:3']
         assert geometry_rel.blocks[6].block_def.nco == decoded['nco:2:4']
-        assert abs(geometry_rel.blocks[3].block_def.phi_r - 0.36728000000000005) < 1e-6
+        assert abs(geometry_rel.blocks[3].block_def.phi_r - 0.6815002146175938) < 1e-6
         assert abs(geometry_rel.blocks[4].block_def.phi_r - 2.6875) < 1e-6
-        assert abs(geometry_rel.blocks[5].block_def.phi_r - 4.687980134528118) < 1e-6
-        assert abs(geometry_rel.blocks[6].block_def.phi_r - 2.9817387771470436) < 1e-6
+        assert abs(geometry_rel.blocks[5].block_def.phi_r - 4.7175114201345) < 1e-6
+        assert abs(geometry_rel.blocks[6].block_def.phi_r - 2.9930119533340758) < 1e-6
         assert geometry_rel.layer_defs[1].blocks == [4, 5, 6, 7]
 
         assert geometry_rel.blocks[7].block_def.nco == decoded['nco:3:1']
@@ -434,17 +434,17 @@ class TestRoxieGeneticOptimization(TestCase):
         assert geometry_rel.blocks[9].block_def.nco == decoded['nco:3:3']
         assert geometry_rel.blocks[10].block_def.nco == decoded['nco:3:4']
         assert geometry_rel.blocks[11].block_def.nco == decoded['nco:3:5']
-        assert abs(geometry_rel.blocks[7].block_def.phi_r - 0.27026000000000006) < 1e-6
-        assert abs(geometry_rel.blocks[8].block_def.phi_r - 1.5312500000000036) < 1e-6
-        assert abs(geometry_rel.blocks[9].block_def.phi_r - 3.3083157703344455) < 1e-6
-        assert abs(geometry_rel.blocks[10].block_def.phi_r - 1.8477476515923072) < 1e-6
-        assert abs(geometry_rel.blocks[11].block_def.phi_r - 3.233679538776819) < 1e-6
+        assert abs(geometry_rel.blocks[7].block_def.phi_r - 0.5058179100635234) < 1e-6
+        assert abs(geometry_rel.blocks[8].block_def.phi_r - 1.53125) < 1e-6
+        assert abs(geometry_rel.blocks[9].block_def.phi_r - 3.31181105191326) < 1e-6
+        assert abs(geometry_rel.blocks[10].block_def.phi_r - 1.8474473698327927) < 1e-6
+        assert abs(geometry_rel.blocks[11].block_def.phi_r - 3.232528774389529) < 1e-6
         assert geometry_rel.layer_defs[2].blocks == [8, 9, 10, 11, 12]
 
         assert geometry_rel.blocks[12].block_def.nco == decoded['nco:4:1']
         assert geometry_rel.blocks[13].block_def.nco == decoded['nco:4:2']
         assert geometry_rel.blocks[14].block_def.nco == decoded['nco:4:3']
-        assert abs(geometry_rel.blocks[12].block_def.phi_r - 0.21236) < 1e-6
-        assert abs(geometry_rel.blocks[13].block_def.phi_r - 2.8437499999999964) < 1e-6
-        assert abs(geometry_rel.blocks[14].block_def.phi_r - 1.990903897948634) < 1e-6
+        assert abs(geometry_rel.blocks[12].block_def.phi_r - 0.3922719871732055) < 1e-6
+        assert abs(geometry_rel.blocks[13].block_def.phi_r - 2.84375) < 1e-6
+        assert abs(geometry_rel.blocks[14].block_def.phi_r - 1.98580819079271) < 1e-6
         assert geometry_rel.layer_defs[3].blocks == [13, 14, 15]
